@@ -28,7 +28,7 @@
 #include "httpengine.h"
 
 #define BING_ENGINE_NAME "Bing"
-#define BING_API_KEY "27318D0A64F53E68850D1745A30B59F324AA0E73"
+#define BING_API_KEY "define_here_your_api_key"
 
 #define TAGS "tags"
 #define TAGS_CONDITION "tagsCondition"
@@ -57,13 +57,13 @@ namespace Bing
     QSize photoSize;
 
     int doCalculateNextIndex(bool randomMode, int currentIndex, int pages) const;
-    QUrl doPrepareInit(QHttpRequestHeader &header);
-    QUrl doPrepareSearch(QHttpRequestHeader &header, bool &shouldEncode);
+    QUrl doPrepareInit(HttpEngine::Operation &op);
+    QUrl doPrepareSearch(HttpEngine::Operation &op);
     bool doProcessSearchResult(const QByteArray &response, int &newPagesCount);
-    QUrl prepareSizeRequest(QHttpRequestHeader &header);
+    QUrl prepareSizeRequest(HttpEngine::Operation &op);
     QSize doProcessSizeRequestResult(const QByteArray &response);
-    QUrl prepareDownload(QHttpRequestHeader &header);
-    QUrl prepareInfoCollect(QHttpRequestHeader &header);
+    QUrl prepareDownload(HttpEngine::Operation &op);
+    QUrl prepareInfoCollect(HttpEngine::Operation &op);
     PhotoInfo doProcessInfoCollectResult(const QByteArray &response);
 
     void doLoadSettings(QSettings &settings);
