@@ -30,6 +30,8 @@
 #define SECONDS_UNIT 2
 
 #define MAIN_SECTION "Main"
+#define DISABLE_SPLASH_SCREEN "disableSplashScreen"
+#define QUIT_AFTER_BACKGROUND_CHANGE "quitAfterBackgroundChange"
 #define RANDOM_SEARCH "randomSearch"
 #define SIZE_CONSTRAINT "sizeConstraint"
 #define INTERVAL "interval"
