@@ -28,8 +28,8 @@
 #include "httpengine.h"
 
 #define PIKEO_ENGINE_NAME "Pikeo"
-#define PIKEO_API_KEY "2e08c229f9cd8f665b7e27392f210c93"
-#define PIKEO_SECRET_KEY "9d159afa57"
+#define PIKEO_API_KEY "insert_here_your_api_key"
+#define PIKEO_SECRET_KEY "insert_here_your_secret_key"
 
 #define TAGS "tags"
 #define SEARCH_ORDER "searchOrder"
@@ -57,13 +57,13 @@ namespace Pikeo
     bool _ascending;
 
     int doCalculateNextIndex(bool randomMode, int currentIndex, int pages) const;
-    QUrl doPrepareInit(QHttpRequestHeader &header);
-    QUrl doPrepareSearch(QHttpRequestHeader &header, bool &shouldEncode);
+    QUrl doPrepareInit(HttpEngine::Operation &op);
+    QUrl doPrepareSearch(HttpEngine::Operation &op);
     bool doProcessSearchResult(const QByteArray &response, int &newPagesCount);
-    QUrl prepareSizeRequest(QHttpRequestHeader &header);
+    QUrl prepareSizeRequest(HttpEngine::Operation &op);
     QSize doProcessSizeRequestResult(const QByteArray &response);
-    QUrl prepareDownload(QHttpRequestHeader &header);
-    QUrl prepareInfoCollect(QHttpRequestHeader &header);
+    QUrl prepareDownload(HttpEngine::Operation &op);
+    QUrl prepareInfoCollect(HttpEngine::Operation &op);
     PhotoInfo doProcessInfoCollectResult(const QByteArray &response);
 
     void doLoadSettings(QSettings &settings);
