@@ -153,6 +153,16 @@
         <source>Danish</source>
         <translation>Dansk</translation>
     </message>
+    <message>
+        <location filename="../../src/about.cpp" line="88"/>
+        <source>Swedish</source>
+        <translation>Svensk</translation>
+    </message>
+    <message>
+        <location filename="../../src/about.cpp" line="90"/>
+        <source>Turkish</source>
+        <translation>Tyrkisk</translation>
+    </message>
 </context>
 <context>
     <name>Bing::DialogWidget</name>
@@ -2488,188 +2498,198 @@ Do you want to delete it anyway?</source>
 <context>
     <name>Wally::Application</name>
     <message>
-        <location filename="../../src/wally.cpp" line="591"/>
+        <location filename="../../src/wally.cpp" line="611"/>
         <source>Cancel</source>
         <translation>Annuller</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="593"/>
-        <location filename="../../src/wally.cpp" line="1985"/>
+        <location filename="../../src/wally.cpp" line="613"/>
+        <location filename="../../src/wally.cpp" line="2008"/>
         <source>Play</source>
         <translation>Afspil</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="595"/>
-        <location filename="../../src/wally.cpp" line="1965"/>
+        <location filename="../../src/wally.cpp" line="615"/>
+        <location filename="../../src/wally.cpp" line="1988"/>
         <source>Pause</source>
         <translation>Pause</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="596"/>
+        <location filename="../../src/wally.cpp" line="616"/>
         <source>Next photo</source>
         <translation>Næste foto</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="597"/>
+        <location filename="../../src/wally.cpp" line="617"/>
         <source>Save photo...</source>
         <translation>Gem foto...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="598"/>
+        <location filename="../../src/wally.cpp" line="618"/>
         <source>Get EXIF info...</source>
         <translation>Hent EXIF info...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="599"/>
+        <location filename="../../src/wally.cpp" line="619"/>
         <source>Settings...</source>
         <translation>Indstillinger...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="600"/>
+        <location filename="../../src/wally.cpp" line="620"/>
         <source>Explore source</source>
         <translation>Undersøg kilde</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="601"/>
+        <location filename="../../src/wally.cpp" line="621"/>
         <source>About...</source>
         <translation>Om...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="602"/>
+        <location filename="../../src/wally.cpp" line="622"/>
         <source>History...</source>
         <translation>Historie...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="603"/>
+        <location filename="../../src/wally.cpp" line="623"/>
         <source>About Qt...</source>
         <translation>Om Qt...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="604"/>
+        <location filename="../../src/wally.cpp" line="624"/>
         <source>Quit</source>
         <translation>Afslut</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="605"/>
+        <location filename="../../src/wally.cpp" line="625"/>
         <source>Languages</source>
         <translation>Sprog</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="607"/>
+        <location filename="../../src/wally.cpp" line="627"/>
         <source>English</source>
         <translation>Engelsk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="608"/>
+        <location filename="../../src/wally.cpp" line="628"/>
         <source>Italian</source>
         <translation>Italiensk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="609"/>
+        <location filename="../../src/wally.cpp" line="629"/>
         <source>Spanish</source>
         <translation>Spansk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="610"/>
+        <location filename="../../src/wally.cpp" line="630"/>
         <source>German</source>
         <translation>Tysk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="611"/>
+        <location filename="../../src/wally.cpp" line="631"/>
         <source>French</source>
         <translation>Fransk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="612"/>
+        <location filename="../../src/wally.cpp" line="632"/>
         <source>Russian</source>
         <translation>Russisk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="613"/>
+        <location filename="../../src/wally.cpp" line="633"/>
         <source>Portuguese (Brazil)</source>
         <translation>Portugisisk (Braziliansk)</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="614"/>
+        <location filename="../../src/wally.cpp" line="634"/>
         <source>Czech</source>
         <translation>Tjekkisk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="615"/>
+        <location filename="../../src/wally.cpp" line="635"/>
         <source>Polish</source>
         <translation>Polsk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="616"/>
+        <location filename="../../src/wally.cpp" line="636"/>
         <source>Chinese</source>
         <translation>Kinesisk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="617"/>
+        <location filename="../../src/wally.cpp" line="637"/>
         <source>Catalan</source>
         <translation>Katalansk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="618"/>
+        <location filename="../../src/wally.cpp" line="638"/>
         <source>Greek</source>
         <translation>Græsk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="619"/>
+        <location filename="../../src/wally.cpp" line="639"/>
         <source>Korean</source>
         <translation>Koreansk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="620"/>
+        <location filename="../../src/wally.cpp" line="640"/>
         <source>Hungarian</source>
         <translation>Ungarsk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="621"/>
+        <location filename="../../src/wally.cpp" line="641"/>
         <source>Danish</source>
         <translation>Dansk</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1556"/>
+        <location filename="../../src/wally.cpp" line="642"/>
+        <source>Swedish</source>
+        <translation>Svensk</translation>
+    </message>
+    <message>
+        <location filename="../../src/wally.cpp" line="643"/>
+        <source>Turkish</source>
+        <translation>Tyrkisk</translation>
+    </message>
+    <message>
+        <location filename="../../src/wally.cpp" line="1579"/>
         <source>Wally Error</source>
         <translation>Wally fejl</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1556"/>
+        <location filename="../../src/wally.cpp" line="1579"/>
         <source>Active Desktop must be disabled</source>
         <translation>Det aktive skrivebord skal deaktiveres</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1645"/>
-        <location filename="../../src/wally.cpp" line="1936"/>
+        <location filename="../../src/wally.cpp" line="1668"/>
+        <location filename="../../src/wally.cpp" line="1959"/>
         <source>by:</source>
         <translation>af:</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1654"/>
+        <location filename="../../src/wally.cpp" line="1677"/>
         <source>Location:</source>
         <translation>Lokation:</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1662"/>
-        <location filename="../../src/wally.cpp" line="1941"/>
+        <location filename="../../src/wally.cpp" line="1685"/>
+        <location filename="../../src/wally.cpp" line="1964"/>
         <source>Engine:</source>
         <translation>Motor:</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="2025"/>
-        <location filename="../../src/wally.cpp" line="2028"/>
+        <location filename="../../src/wally.cpp" line="2048"/>
+        <location filename="../../src/wally.cpp" line="2051"/>
         <source>Save photo</source>
         <translation>Gem foto</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="2026"/>
-        <location filename="../../src/wally.cpp" line="2030"/>
+        <location filename="../../src/wally.cpp" line="2049"/>
+        <location filename="../../src/wally.cpp" line="2053"/>
         <source>Images (*.png *.xpm *.jpg)</source>
         <translation>Billedtyper (*.png *.xpm *.jpg)</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="2525"/>
+        <location filename="../../src/wally.cpp" line="2548"/>
         <source>Right-click to show main menu</source>
         <translation>Højreklik for at vise hovedmenu</translation>
     </message>
