@@ -123,6 +123,14 @@
         <source>Danish</source>
         <translation>Dán</translation>
     </message>
+    <message>
+        <source>Swedish</source>
+        <translation>Svéd</translation>
+    </message>
+    <message>
+        <source>Turkish</source>
+        <translation>Török</translation>
+    </message>
 </context>
 <context>
     <name>Bing::DialogWidget</name>
@@ -2149,6 +2157,14 @@ Do you want to delete it anyway?</source>
         <source>Danish</source>
         <translation>Dán</translation>
     </message>
+    <message>
+        <source>Swedish</source>
+        <translation>Svéd</translation>
+    </message>
+    <message>
+        <source>Turkish</source>
+        <translation>Török</translation>
+    </message>
 </context>
 <context>
     <name>Yahoo::DialogWidget</name>
