@@ -78,6 +78,16 @@
         <source>Danish</source>
         <translation>丹麦的</translation>
     </message>
+    <message>
+        <location filename="../../src/about.cpp" line="88"/>
+        <source>Swedish</source>
+        <translation>瑞典语</translation>
+    </message>
+    <message>
+        <location filename="../../src/about.cpp" line="90"/>
+        <source>Turkish</source>
+        <translation>土耳其</translation>
+    </message>
     <message>
         <location filename="../../src/about.cpp" line="74"/>
         <source>Chinese</source>
@@ -2483,188 +2493,198 @@ Do you want to delete it anyway?</source>
 <context>
     <name>Wally::Application</name>
     <message>
-        <location filename="../../src/wally.cpp" line="591"/>
+        <location filename="../../src/wally.cpp" line="611"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="593"/>
-        <location filename="../../src/wally.cpp" line="1985"/>
+        <location filename="../../src/wally.cpp" line="613"/>
+        <location filename="../../src/wally.cpp" line="2008"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="595"/>
-        <location filename="../../src/wally.cpp" line="1965"/>
+        <location filename="../../src/wally.cpp" line="615"/>
+        <location filename="../../src/wally.cpp" line="1988"/>
         <source>Pause</source>
         <translation>暂停</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="596"/>
+        <location filename="../../src/wally.cpp" line="616"/>
         <source>Next photo</source>
         <translation>下一张图片</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="597"/>
+        <location filename="../../src/wally.cpp" line="617"/>
         <source>Save photo...</source>
         <translation>保存图片...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="598"/>
+        <location filename="../../src/wally.cpp" line="618"/>
         <source>Get EXIF info...</source>
         <translation>获取 EXIF信息...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="599"/>
+        <location filename="../../src/wally.cpp" line="619"/>
         <source>Settings...</source>
         <translation>设置...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="600"/>
+        <location filename="../../src/wally.cpp" line="620"/>
         <source>Explore source</source>
         <translation>浏览原文件</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="601"/>
+        <location filename="../../src/wally.cpp" line="621"/>
         <source>About...</source>
         <translation>关于...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="602"/>
+        <location filename="../../src/wally.cpp" line="622"/>
         <source>History...</source>
         <translation>历史记录...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="603"/>
+        <location filename="../../src/wally.cpp" line="623"/>
         <source>About Qt...</source>
         <translation>关于 Qt...</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="604"/>
+        <location filename="../../src/wally.cpp" line="624"/>
         <source>Quit</source>
         <translation>退出</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="607"/>
+        <location filename="../../src/wally.cpp" line="627"/>
         <source>English</source>
         <translation>英语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="608"/>
+        <location filename="../../src/wally.cpp" line="628"/>
         <source>Italian</source>
         <translation>意大利语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="609"/>
+        <location filename="../../src/wally.cpp" line="629"/>
         <source>Spanish</source>
         <translation>西班牙语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="610"/>
+        <location filename="../../src/wally.cpp" line="630"/>
         <source>German</source>
         <translation>德语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="611"/>
+        <location filename="../../src/wally.cpp" line="631"/>
         <source>French</source>
         <translation>法语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="612"/>
+        <location filename="../../src/wally.cpp" line="632"/>
         <source>Russian</source>
         <translation>俄语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="613"/>
+        <location filename="../../src/wally.cpp" line="633"/>
         <source>Portuguese (Brazil)</source>
         <translation>葡萄牙语（巴西）</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="614"/>
+        <location filename="../../src/wally.cpp" line="634"/>
         <source>Czech</source>
         <translation>捷克语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="615"/>
+        <location filename="../../src/wally.cpp" line="635"/>
         <source>Polish</source>
         <translation>波兰文</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="616"/>
+        <location filename="../../src/wally.cpp" line="636"/>
         <source>Chinese</source>
         <translation>汉语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="605"/>
+        <location filename="../../src/wally.cpp" line="625"/>
         <source>Languages</source>
         <translation>语言</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="617"/>
+        <location filename="../../src/wally.cpp" line="637"/>
         <source>Catalan</source>
         <translation>加泰罗尼亚语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="618"/>
+        <location filename="../../src/wally.cpp" line="638"/>
         <source>Greek</source>
         <translation>希腊</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="619"/>
+        <location filename="../../src/wally.cpp" line="639"/>
         <source>Korean</source>
         <translation>韩语</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="620"/>
+        <location filename="../../src/wally.cpp" line="640"/>
         <source>Hungarian</source>
         <translation>匈牙利</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="621"/>
+        <location filename="../../src/wally.cpp" line="641"/>
         <source>Danish</source>
         <translation>丹麦的</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1556"/>
+        <location filename="../../src/wally.cpp" line="642"/>
+        <source>Swedish</source>
+        <translation>瑞典语</translation>
+    </message>
+    <message>
+        <location filename="../../src/wally.cpp" line="643"/>
+        <source>Turkish</source>
+        <translation>土耳其</translation>
+    </message>
+    <message>
+        <location filename="../../src/wally.cpp" line="1579"/>
         <source>Wally Error</source>
         <translation>Wally 错误</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1556"/>
+        <location filename="../../src/wally.cpp" line="1579"/>
         <source>Active Desktop must be disabled</source>
         <translation>请禁止使用动态桌面</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1645"/>
-        <location filename="../../src/wally.cpp" line="1936"/>
+        <location filename="../../src/wally.cpp" line="1668"/>
+        <location filename="../../src/wally.cpp" line="1959"/>
         <source>by:</source>
         <translation>通过:</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1654"/>
+        <location filename="../../src/wally.cpp" line="1677"/>
         <source>Location:</source>
         <translation>地点:</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="1662"/>
-        <location filename="../../src/wally.cpp" line="1941"/>
+        <location filename="../../src/wally.cpp" line="1685"/>
+        <location filename="../../src/wally.cpp" line="1964"/>
         <source>Engine:</source>
         <translation>引擎:</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="2025"/>
-        <location filename="../../src/wally.cpp" line="2028"/>
+        <location filename="../../src/wally.cpp" line="2048"/>
+        <location filename="../../src/wally.cpp" line="2051"/>
         <source>Save photo</source>
         <translation>保存图片</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="2026"/>
-        <location filename="../../src/wally.cpp" line="2030"/>
+        <location filename="../../src/wally.cpp" line="2049"/>
+        <location filename="../../src/wally.cpp" line="2053"/>
         <source>Images (*.png *.xpm *.jpg)</source>
         <translation>图片格式 (*.png *.xpm *.jpg)</translation>
     </message>
     <message>
-        <location filename="../../src/wally.cpp" line="2525"/>
+        <location filename="../../src/wally.cpp" line="2548"/>
         <source>Right-click to show main menu</source>
         <translation>右键单击显示主菜单</translation>
     </message>
