@@ -27,9 +27,6 @@ TRANSLATOR Flickr::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtXml>
 
 #include "httpengine.h"
@@ -102,7 +99,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int pages) con
   return (pages)? (currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1)) % pages : 1;
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   _photoId.clear();
   _photoUrl.clear();
@@ -110,7 +107,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://api.flickr.com/services/rest");
 
@@ -162,7 +159,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
   return (!respError && !_photoId.isEmpty() && !_lastPhotoIds.contains(_photoId));
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://api.flickr.com/services/rest");
 
@@ -262,12 +259,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray &response)
   return QSize(-1,-1);
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return _photoUrl;
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   QUrl url("http://api.flickr.com/services/rest");
 
