@@ -27,13 +27,9 @@ TRANSLATOR HttpEngine::SettingsWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtDebug>
 
 #include "diskinfo.h"
-#include "httpex.h"
 #include "engine.h"
 #include "httpengine.h"
 
@@ -42,7 +38,7 @@ using namespace HttpEngine;
 Item::Item()
 {
   _savePhotos = false;
-  _pageIndex = _pages = 0;
+  _pageIndex = _pages = _consecutiveSearchesFailed = 0;
 }
 
 Item::Item(Item *item)
@@ -51,6 +47,7 @@ Item::Item(Item *item)
   _pages = item->_pages;
   _savePhotos = item->_savePhotos;
   _photosPath = item->_photosPath;
+  _consecutiveSearchesFailed = item->_consecutiveSearchesFailed;
 }
 
 void Item::loadState(QSettings &settings, const QString &group)
@@ -101,11 +98,11 @@ void Item::saveSettings(QSettings &settings, const QString &engineName, int id)
   settings.endGroup();
 }
 
-QUrl Item::prepareInit(QHttpRequestHeader &header)
+QUrl Item::prepareInit(Operation &op)
 {
   qDebug() << metaObject()->className() << "::prepareInit()";
 
-  return doPrepareInit(header);
+  return doPrepareInit(op);
 }
 
 void Item::processInitResult(const QByteArray &response)
@@ -122,7 +119,7 @@ void Item::processInitResult(const QByteArray &response)
   doProcessInitResult(response);
 }
 
-QUrl Item::prepareSearch(bool randomMode, QHttpRequestHeader &header, bool &shouldEncode)
+QUrl Item::prepareSearch(bool randomMode, Operation &op)
 {
   QString debugMsg = QString(metaObject()->className()) + "::doCalculateNextIndex(" + ((randomMode)? "true" : "false") +
                      "," + QString::number(_pageIndex) + "," + QString::number(_pages) + ") ->";
@@ -136,7 +133,7 @@ QUrl Item::prepareSearch(bool randomMode, QHttpRequestHeader &header, bool &shou
 
   qDebug() << debugMsg << _pageIndex;
 
-  return doPrepareSearch(header,shouldEncode);
+  return doPrepareSearch(op);
 }
 
 bool Item::processSearchResult(const QByteArray &response)
@@ -150,7 +147,18 @@ bool Item::processSearchResult(const QByteArray &response)
 
   qDebug() << debugMsg;
 
-  return doProcessSearchResult(response,_pages);
+  if (doProcessSearchResult(response,_pages))
+  {
+    _consecutiveSearchesFailed = 0;
+    return true;
+  }
+  else
+  {
+    ++_consecutiveSearchesFailed;
+    if (_consecutiveSearchesFailed > 20)
+      resetPages();
+    return false;
+  }
 }
 
 QSize Item::processSizeRequestResult(const QByteArray &response)
@@ -206,21 +214,13 @@ PhotoInfo Item::processInfoCollectResult(const QByteArray &response)
 Core::Core(const QString &tempStorageDir, QObject *parent) : XtEngine::Core(tempStorageDir,parent),
   httpProxy(QNetworkProxy::NoProxy)
 {
-  HttpEx::Interface *retry;
-
   canceling = cancelSignaled = false;
-  initHttp = new HttpEx::Timeout(new HttpEx::Log(new HttpEx::Base(new HttpEx::Core(new QHttp(this),this))));
-  searchHttp = new HttpEx::Timeout(new HttpEx::Log(new HttpEx::Base(new HttpEx::Core(new QHttp(this),this))));
-  sizeRequestHttp = new HttpEx::Timeout(new HttpEx::Log(new HttpEx::Base(new HttpEx::Core(new QHttp(this),this))));
-  retry = new HttpEx::Retry(new HttpEx::Log(new HttpEx::Base(new HttpEx::Core(new QHttp(this),this))));
-  downloadHttp = new HttpEx::Timeout(retry);
-  infoCollectHttp = new HttpEx::Timeout(new HttpEx::Log(new HttpEx::Base(new HttpEx::Core(new QHttp(this),this))));
 
-  connect(initHttp,SIGNAL(done(bool)),this,SLOT(httpInitDone(bool)));
-  connect(searchHttp,SIGNAL(done(bool)),this,SLOT(httpSearchDone(bool)));
-  connect(sizeRequestHttp,SIGNAL(done(bool)),this,SLOT(httpSizeRequestDone(bool)));
-  connect(qobject_cast<HttpEx::Retry *> (retry),SIGNAL(completed(bool, const QByteArray &)),this,SLOT(httpDownloadDone(bool)));
-  connect(infoCollectHttp,SIGNAL(done(bool)),this,SLOT(httpInfoCollectDone(bool)));
+  initHttp = new Network::Manager(this);
+  searchHttp = new Network::Manager(this);
+  sizeRequestHttp = new Network::Manager(this);
+  downloadHttp = new Network::Manager(this);
+  infoCollectHttp = new Network::Manager(this);
 }
 
 void Core::setProxy(const QNetworkProxy &proxy)
@@ -255,19 +255,15 @@ QNetworkProxy Core::guessProxy(const QUrl &url)
 
 void Core::init()
 {
-  QUrl url;
-  QString urlStr;
-  QHttpRequestHeader header;
-
   qDebug() << name().toAscii().constData() << "::Core::init()";
 
   canceling = cancelSignaled = false;
 
   if (list.size())
   {
+    Operation op = Get;
     currentItemIndex = (currentItemIndex + 1) % list.size();
-
-    url = qobject_cast<Item *> (list.at(currentItemIndex))->prepareInit(header);
+    QUrl url(qobject_cast<Item *> (list.at(currentItemIndex))->prepareInit(op));
 
     qDebug() << "\tURL: " << (!(url.isEmpty())? url.toString().toAscii().constData() : "empty");
 
@@ -280,14 +276,22 @@ void Core::init()
       else
         initHttp->setProxy(httpProxy);
 
-      initHttp->setHost(url.host());
+      switch (op)
+      {
+        case Get:
+          currentReply = initHttp->get(url);
+          break;
 
-      urlStr = url.toEncoded();
+        case Post:
+          currentReply = initHttp->post(url);
+          break;
 
-      if (header.keys().size())
-        initHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
-      else
-        initHttp->get(urlStr.remove(0,urlStr.indexOf(url.path())));
+        default:
+          emit initCompleted();
+          return;
+      }
+
+      connect(currentReply.data(),SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpInitDone(bool,const QByteArray &)));
     }
   }
   else
@@ -296,18 +300,14 @@ void Core::init()
 
 void Core::search(bool randomMode)
 {
-  QUrl url;
-  QString urlStr;
-  QHttpRequestHeader header;
-  bool shouldEncode = true;
-
   qDebug() << name().toAscii().constData() << "::Core::search(" << randomMode << ")";
 
   if (list.size())
   {
-    url = qobject_cast<Item *> (list.at(currentItemIndex))->prepareSearch(randomMode,header,shouldEncode);
+    Operation op = Get;
+    QUrl url(qobject_cast<Item *> (list.at(currentItemIndex))->prepareSearch(randomMode,op));
 
-    qDebug() << "\tURL:" << (!(url.isEmpty())? url.toEncoded().constData() : "empty");
+    qDebug() << "\tURL:" << (!(url.isEmpty())? url.toString().toAscii().constData() : "empty");
 
     if (url.isEmpty())
       emit searchCompleted(false);
@@ -320,20 +320,22 @@ void Core::search(bool randomMode)
       else
         searchHttp->setProxy(httpProxy);
 
-      searchHttp->setHost(url.host());
-
-      urlStr = (shouldEncode)? url.toEncoded() : url.toString();
-
-      if (header.keys().size())
-        searchHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
-      else
+      switch (op)
       {
-        if (shouldEncode)
-          searchHttp->get(urlStr.remove(0,urlStr.indexOf(url.path())));
-        else
-          searchHttp->get(url.encodedPath() + urlStr.remove(0,urlStr.indexOf(url.path()) +
-                                                            url.path().size()));
+        case Get:
+          currentReply = searchHttp->get(url);
+          break;
+
+        case Post:
+          currentReply = searchHttp->post(url);
+          break;
+
+        default:
+          emit searchCompleted(false);
+          return;
       }
+
+      connect(currentReply.data(),SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpSearchDone(bool,const QByteArray &)));
     }
   }
   else
@@ -342,10 +344,9 @@ void Core::search(bool randomMode)
 
 void Core::sizeLookup()
 {
+  Operation op = Get;
   Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-  QString urlStr;
-  QHttpRequestHeader header;
-  QUrl url = item->prepareSizeRequest(header);
+  QUrl url(item->prepareSizeRequest(op));
 
   qDebug() << name().toAscii().constData() << "::Core::sizeLookup()";
   qDebug() << "\tURL: " << (!(url.isEmpty())? url.toString().toAscii().constData() : "empty");
@@ -359,14 +360,22 @@ void Core::sizeLookup()
     else
       sizeRequestHttp->setProxy(httpProxy);
 
-    sizeRequestHttp->setHost(url.host());
+      switch (op)
+      {
+        case Get:
+          currentReply = sizeRequestHttp->get(url);
+          break;
 
-    urlStr = url.toEncoded();
+        case Post:
+          currentReply = sizeRequestHttp->post(url);
+          break;
 
-    if (header.keys().size())
-      sizeRequestHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
-    else
-      sizeRequestHttp->get(urlStr.remove(0,urlStr.indexOf(url.path())));
+        default:
+          emit sizeLookupCompleted(QSize(-1,-1));
+          return;
+      }
+
+    connect(currentReply.data(),SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpSizeRequestDone(bool,const QByteArray &)));
   }
   else
     emit sizeLookupCompleted(item->processSizeRequestResult(QByteArray()));
@@ -374,18 +383,15 @@ void Core::sizeLookup()
 
 void Core::download()
 {
-  QString urlStr;
-  QHttpRequestHeader header;
-  QUrl url = qobject_cast<Item *> (list.at(currentItemIndex))->prepareDownload(header);
+  Operation op = Get;
+  QUrl url(qobject_cast<Item *> (list.at(currentItemIndex))->prepareDownload(op));
 
-  httpFile.setFileName(tempStorageDir() + "/" + QFileInfo(url.path()).fileName());
+  httpFile = tempStorageDir() + "/" + QFileInfo(url.path()).fileName();
 
   qDebug() << name().toAscii().constData() << "::Core::download()";
   qDebug() << "\tURL: "
            << (!(url.isEmpty())? url.toString().toAscii().constData() : "empty");
 
-  httpFile.open(QIODevice::WriteOnly);
-
   if (url.isEmpty())
     emit downloadCompleted(false,QFileInfo());
   else
@@ -395,20 +401,17 @@ void Core::download()
     else
       downloadHttp->setProxy(httpProxy);
 
-    downloadHttp->setHost(url.host());
+    currentReply = downloadHttp->get(url,httpFile.absoluteFilePath());
 
-    urlStr = url.toEncoded();
-
-    downloadHttp->get(urlStr.remove(0,urlStr.indexOf(url.encodedPath())),&httpFile);
+    connect(currentReply.data(),SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpDownloadDone(bool,const QByteArray &)));
   }
 }
 
 void Core::infoCollect()
 {
+  Operation op = Get;
   Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-  QString urlStr;
-  QHttpRequestHeader header;
-  QUrl url = item->prepareInfoCollect(header);
+  QUrl url(item->prepareInfoCollect(op));
 
   qDebug() << name().toAscii().constData() << "::Core::infoCollect()";
   qDebug() << "\tURL: " << (!(url.isEmpty())? url.toString().toAscii().constData() : "empty");
@@ -422,14 +425,22 @@ void Core::infoCollect()
     else
       infoCollectHttp->setProxy(httpProxy);
 
-    infoCollectHttp->setHost(url.host());
+      switch (op)
+      {
+        case Get:
+          currentReply = infoCollectHttp->get(url);
+          break;
 
-    urlStr = url.toEncoded();
+        case Post:
+          currentReply = infoCollectHttp->post(url);
+          break;
 
-    if (header.keys().size())
-      infoCollectHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
-    else
-      infoCollectHttp->get(urlStr.remove(0,urlStr.indexOf(url.path())));
+        default:
+          emit infoCollectCompleted(PhotoInfo());
+          return;
+      }
+
+    connect(currentReply.data(),SIGNAL(finished(bool,const QByteArray &)),this,SLOT(httpInfoCollectDone(bool,const QByteArray &)));
   }
   else
     emit infoCollectCompleted(item->processInfoCollectResult(QByteArray()));
@@ -442,21 +453,18 @@ void Core::cancel()
   canceling = true;
   cancelSignaled = false;
 
-  initHttp->abort();
-  searchHttp->abort();
-  sizeRequestHttp->abort();
-  downloadHttp->abort();
-  infoCollectHttp->abort();
+  if (!currentReply.isNull())
+    currentReply->abort();
 }
 
-void Core::httpInitDone(bool error)
+void Core::httpInitDone(bool ok, const QByteArray &data)
 {
-  qDebug() << name().toAscii().constData() << "::Core::httpInitDone(" << error << ")";
+  qDebug() << name().toAscii().constData() << "::Core::httpInitDone(" << ok << ")";
 
-  if (!error && initHttp->bytesAvailable())
+  if (ok && !data.isEmpty())
   {
     Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-    item->processInitResult(initHttp->readAll());
+    item->processInitResult(data);
   }
 
   if (canceling)
@@ -469,11 +477,13 @@ void Core::httpInitDone(bool error)
   }
   else
     emit initCompleted();
+
+  sender()->deleteLater();
 }
 
-void Core::httpSearchDone(bool error)
+void Core::httpSearchDone(bool ok, const QByteArray &data)
 {
-  qDebug() << name().toAscii().constData() << "::Core::httpSearchDone(" << error << ")";
+  qDebug() << name().toAscii().constData() << "::Core::httpSearchDone(" << ok << ")";
 
   if (canceling)
   {
@@ -483,23 +493,25 @@ void Core::httpSearchDone(bool error)
       emit cancelCompleted();
     }
   }
-  else if (!error)
+  else if (ok)
   {
-    if (searchHttp->bytesAvailable())
+    if (!data.isEmpty())
     {
       Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-      emit searchCompleted(item->processSearchResult(searchHttp->readAll()));
+      emit searchCompleted(item->processSearchResult(data));
     }
     else
       emit searchCompleted(false);
   }
   else
     emit searchCompleted(false);
+
+  sender()->deleteLater();
 }
 
-void Core::httpSizeRequestDone(bool error)
+void Core::httpSizeRequestDone(bool ok, const QByteArray &data)
 {
-  qDebug() << name().toAscii().constData() << "::Core::httpSizeRequestDone(" << error << ")";
+  qDebug() << name().toAscii().constData() << "::Core::httpSizeRequestDone(" << ok << ")";
 
   if (canceling)
   {
@@ -509,25 +521,25 @@ void Core::httpSizeRequestDone(bool error)
       emit cancelCompleted();
     }
   }
-  else if (!error)
+  else if (ok)
   {
-    if (sizeRequestHttp->bytesAvailable())
+    if (!data.isEmpty())
     {
       Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-      emit sizeLookupCompleted(item->processSizeRequestResult(sizeRequestHttp->readAll()));
+      emit sizeLookupCompleted(item->processSizeRequestResult(data));
     }
     else
       emit sizeLookupCompleted(QSize(-1,-1));
   }
   else
     emit sizeLookupCompleted(QSize(-1,-1));
+
+  sender()->deleteLater();
 }
 
-void Core::httpDownloadDone(bool error)
+void Core::httpDownloadDone(bool ok, const QByteArray & /* data */)
 {
-  httpFile.close();
-
-  qDebug() << name().toAscii().constData() << "::Core::httpDownloadDone(" << error << ")";
+  qDebug() << name().toAscii().constData() << "::Core::httpDownloadDone(" << ok << ")";
 
   if (canceling)
   {
@@ -537,23 +549,23 @@ void Core::httpDownloadDone(bool error)
       emit cancelCompleted();
     }
   }
-  else if (!error)
+  else if (ok)
   {
-    QFileInfo httpFileInfo = QFileInfo(httpFile);
-
     Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-    item->processDownloadResult(httpFileInfo,
-                                DiskInfo::freeSpace(httpFileInfo.absoluteFilePath()) <=
-                                (_diskSpaceThreshold + httpFileInfo.size()));
-    emit downloadCompleted(true,QFileInfo(httpFile));
+    item->processDownloadResult(httpFile,
+                                DiskInfo::freeSpace(httpFile.absoluteFilePath()) <=
+                                (_diskSpaceThreshold + httpFile.size()));
+    emit downloadCompleted(true,httpFile);
   }
   else
     emit downloadCompleted(false,QFileInfo());
+
+  sender()->deleteLater();
 }
 
-void Core::httpInfoCollectDone(bool error)
+void Core::httpInfoCollectDone(bool ok, const QByteArray &data)
 {
-  qDebug() << name().toAscii().constData() << "::Core::httpInfoCollectDone(" << error << ")";
+  qDebug() << name().toAscii().constData() << "::Core::httpInfoCollectDone(" << ok << ")";
 
   if (canceling)
   {
@@ -563,18 +575,20 @@ void Core::httpInfoCollectDone(bool error)
       emit cancelCompleted();
     }
   }
-  else if (!error)
+  else if (ok)
   {
-    if (infoCollectHttp->bytesAvailable())
+    if (!data.isEmpty())
     {
       Item *item = qobject_cast<Item *> (list.at(currentItemIndex));
-      emit infoCollectCompleted(item->processInfoCollectResult(infoCollectHttp->readAll()));
+      emit infoCollectCompleted(item->processInfoCollectResult(data));
     }
     else
       emit infoCollectCompleted(PhotoInfo());
   }
   else
     emit infoCollectCompleted(PhotoInfo());
+
+  sender()->deleteLater();
 }
 
 SettingsWidget::SettingsWidget(Engine::Core *core, QWidget *parent)
