@@ -17,7 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#if (!defined(QT_SHARED)) && (!defined(QT_DLL))
+#ifdef WALLY_STATIC
   #include <QtPlugin>
 
   Q_IMPORT_PLUGIN(qgif)
@@ -45,13 +45,19 @@
 #include "picasa.h"
 #include "smugmug.h"
 #include "bing.h"
+#include "google.h"
+#include "vladstudio.h"
+#include "deviantart.h"
 #include "wally.h"
+#include "defs.h"
 
 int main(int argc, char **argv)
 {
   int err = 0;
   Wally::Application *wally = new Wally::Application(argc,argv);
 
+  wally->loadLanguages();
+
   if (!wally->isCommandLineHelp())
   {
     if (!wally->isSingleInstance())
@@ -87,81 +93,139 @@ int main(int argc, char **argv)
       {
         wally->initialize();
 
-        SplashScreen *splash = new SplashScreen;
+        QSettings sourceSettings;
 
-        splash->show();
+        sourceSettings.beginGroup(MAIN_SECTION);
+        bool splashScreenDisabled = sourceSettings.value(DISABLE_SPLASH_SCREEN,false).toBool();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Files module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        SplashScreen *splash = 0;
+        if (!splashScreenDisabled)
+        {
+          splash = new SplashScreen;
+          splash->show();
+        }
+
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Files module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Files::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Folders module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Folders module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Folders::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Flickr module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Flickr module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Flickr::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Yahoo! module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Yahoo! module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Yahoo::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Panoramio module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Panoramio module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Panoramio::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Pikeo module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
-        wally->addEngine(new Pikeo::Core(wally->tempStorageDir()));
-        splash->repaint();
+//        if (!splashScreenDisabled)
+//          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Pikeo module ..."),
+//                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
+//        wally->addEngine(new Pikeo::Core(wally->tempStorageDir()));
+//        if (!splashScreenDisabled)
+//          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Ipernity module ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Ipernity module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Ipernity::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Photobucket module ..."),
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Photobucket module ..."),
                               Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Photobucket::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Buzznet module ..."),
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Buzznet module ..."),
                               Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Buzznet::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Picasa module ..."),
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Picasa module ..."),
                               Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new Picasa::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading SmugMug module ..."),
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading SmugMug module ..."),
                               Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->addEngine(new SmugMug::Core(wally->tempStorageDir()));
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Bing module ..."),
+//        if (!splashScreenDisabled)
+//          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Bing module ..."),
+//                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
+//        wally->addEngine(new Bing::Core(wally->tempStorageDir()));
+//        if (!splashScreenDisabled)
+//          splash->repaint();
+
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Google module ..."),
                               Qt::AlignRight | Qt::AlignBottom,Qt::white);
-        wally->addEngine(new Bing::Core(wally->tempStorageDir()));
-        splash->repaint();
+        wally->addEngine(new Google::Core(wally->tempStorageDir()));
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Loading settings ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading Vladstudio module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        wally->addEngine(new Vladstudio::Core(wally->tempStorageDir()));
+        if (!splashScreenDisabled)
+          splash->repaint();
+
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading deviantART module ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        wally->addEngine(new DeviantArt::Core(wally->tempStorageDir()));
+        if (!splashScreenDisabled)
+          splash->repaint();
+
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Loading settings ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->loadSettings();
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        splash->showMessage(QCoreApplication::translate("SplashScreen","Launching Wally ..."),
-                            Qt::AlignRight | Qt::AlignBottom,Qt::white);
+        if (!splashScreenDisabled)
+          splash->showMessage(QCoreApplication::translate("SplashScreen","Launching Wally ..."),
+                              Qt::AlignRight | Qt::AlignBottom,Qt::white);
         wally->setupBeforeLaunch();
-        splash->repaint();
+        if (!splashScreenDisabled)
+          splash->repaint();
 
-        QTimer::singleShot(3000,splash,SLOT(deleteLater()));
+        if (!splashScreenDisabled)
+          QTimer::singleShot(3000,splash,SLOT(deleteLater()));
         if (upgraded)
           QTimer::singleShot(6000,wally,SLOT(showTrayMessage()));
 
