@@ -27,9 +27,6 @@ TRANSLATOR Pikeo::DialogWidget
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <QtCore>
-#include <QtGui>
-#include <QtNetwork>
 #include <QtXml>
 
 #include "httpengine.h"
@@ -80,7 +77,7 @@ int Item::doCalculateNextIndex(bool randomMode, int currentIndex, int /* pages *
   return currentIndex + ((randomMode)? (qrand() % 5) + 1 : 1);
 }
 
-QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareInit(HttpEngine::Operation & /* op */)
 {
   _photoId.clear();
   urlPrefix.clear();
@@ -93,17 +90,15 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader &header, bool & /* shouldEncode */)
+QUrl Item::doPrepareSearch(HttpEngine::Operation &op)
 {
-  QUrl url("http://api.pikeo.com");
+  QUrl url("http://api.pikeo.com/services/pikeo/v2/rest");
   QCryptographicHash hash(QCryptographicHash::Sha1);
   QByteArray nonce;
   QByteArray nonceTimestampStr = QDateTime::currentDateTime().toString(Qt::ISODate).toAscii() + "Z";
   int nonceLength = (qrand() % 10) + 10;
 
-  header.setRequest("POST","/services/pikeo/v2/rest/");
-  header.setValue("Host","api.pikeo.com");
-  header.setContentType("application/x-www-form-urlencoded");
+  op = HttpEngine::Post;
 
   while (--nonceLength)
     nonce += qrand() % 10 + 0x30;
@@ -182,7 +177,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int & /* newPagesCo
          !urlPrefix.isEmpty() && !urlFile.isEmpty();
 }
 
-QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
+QUrl Item::prepareSizeRequest(HttpEngine::Operation & /* op */)
 {
   return QUrl("/");
 }
@@ -192,12 +187,12 @@ QSize Item::doProcessSizeRequestResult(const QByteArray & /* response */)
   return photoSize;
 }
 
-QUrl Item::prepareDownload(QHttpRequestHeader & /* header */)
+QUrl Item::prepareDownload(HttpEngine::Operation & /* op */)
 {
   return QUrl(urlPrefix + urlFile);
 }
 
-QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
+QUrl Item::prepareInfoCollect(HttpEngine::Operation & /* op */)
 {
   _lastPhotoIds.insert(_photoId);
   return QUrl("/");
