@@ -237,6 +237,14 @@ void Application::loadLanguages()
   translator->load(":/languages/danish");
   translators[QLocale(QLocale::Danish,QLocale::Denmark).name()] = translator;
 
+  translator = new QTranslator(this);
+  translator->load(":/languages/swedish");
+  translators[QLocale(QLocale::Swedish,QLocale::Sweden).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/turkish");
+  translators[QLocale(QLocale::Turkish,QLocale::Turkey).name()] = translator;
+
   currentLocale = QLocale::English;
   settings.beginGroup(MAIN_SECTION);
   changeLanguage(settings.value(LOCALE,QLocale::system().name()).toString());
@@ -578,6 +586,18 @@ void Application::setupActions()
                                     QLocale(QLocale::Danish,QLocale::Denmark).name());
   connect(danishLanguageAction,SIGNAL(triggered()),languagesSignalMapper,SLOT(map()));
 
+  swedishLanguageAction = new QAction(QIcon(":/images/sweden"),QString(),this);
+  languagesActions << swedishLanguageAction;
+  languagesSignalMapper->setMapping(swedishLanguageAction,
+                                    QLocale(QLocale::Swedish,QLocale::Sweden).name());
+  connect(swedishLanguageAction,SIGNAL(triggered()),languagesSignalMapper,SLOT(map()));
+
+  turkishLanguageAction = new QAction(QIcon(":/images/turkey"),QString(),this);
+  languagesActions << turkishLanguageAction;
+  languagesSignalMapper->setMapping(turkishLanguageAction,
+                                    QLocale(QLocale::Turkish,QLocale::Turkey).name());
+  connect(turkishLanguageAction,SIGNAL(triggered()),languagesSignalMapper,SLOT(map()));
+
   hiddenWidgetForLanguagesActions->addActions(languagesActions);
 }
 
@@ -619,6 +639,8 @@ void Application::retranslateMenu()
   koreanLanguageAction->setText(tr("Korean"));
   hungarianLanguageAction->setText(tr("Hungarian"));
   danishLanguageAction->setText(tr("Danish"));
+  swedishLanguageAction->setText(tr("Swedish"));
+  turkishLanguageAction->setText(tr("Turkish"));
 
   languagesMenu->clear();
   qSort(languagesActions.begin(),languagesActions.end(),actionCaseSensitiveLessThan);
@@ -675,6 +697,8 @@ void Application::setupMenu()
   languagesMenu->addAction(koreanLanguageAction);
   languagesMenu->addAction(hungarianLanguageAction);
   languagesMenu->addAction(danishLanguageAction);
+  languagesMenu->addAction(swedishLanguageAction);
+  languagesMenu->addAction(turkishLanguageAction);
 
   contextMenu = new QMenu;
   contextMenu->addAction(playAction);
@@ -1474,6 +1498,7 @@ void Application::showPhotoOnScreen()
         QProcess::execute("dcop",args);
         break;
 
+      case wmGnomeShell:
       case wmGnome:
         newFile = adaptPhoto(currentFile.absoluteFilePath(),"PNG",currentPhotoInfo);
         args << "--type" << "bool" << "--set" <<
@@ -1487,9 +1512,8 @@ void Application::showPhotoOnScreen()
         args << "--type" << "string" << "--set" <<
                 "/desktop/gnome/background/picture_filename" << newFile.absoluteFilePath();
         QProcess::execute("gconftool-2",args);
-        break;
 
-      case wmGnomeShell:
+        args.clear();
         newFile = adaptPhoto(currentFile.absoluteFilePath(),"PNG",currentPhotoInfo);
         args << "set" << "org.gnome.desktop.background" << "draw-background" << "true";
         QProcess::execute("gsettings",args);
